@@ -22,7 +22,11 @@ def to_prefecture(postcode: str):
     cleaned_postcode = postcode.replace('-', '')
     filtered = filter(lambda x: x[0] == cleaned_postcode, postcodes)
     prefectures_counter = Counter([x[1] for x in filtered])
-    return prefectures_counter.most_common(1)[0][0]
+    most_common = prefectures_counter.most_common(1)
+    if most_common:
+        return most_common[0][0]
+    else:
+        return None
 
 
 def to_cities(postcode: str):
@@ -36,4 +40,8 @@ def to_city(postcode: str):
     cleaned_postcode = postcode.replace('-', '')
     filtered = filter(lambda x: x[0] == cleaned_postcode, postcodes)
     cities_counter = Counter([x[2] for x in filtered])
-    return cities_counter.most_common(1)[0][0].replace('　', '')
+    most_common = cities_counter.most_common(1)
+    if most_common:
+        return most_common[0][0].replace('　', '')
+    else:
+        return None
